/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/

#define CLASS 1
#define FAMILY 5
#define WEIGHT 3
#define SLANT 3
#define SIZE 26

#define ADOBE 0

#define COURIER 0
#define HELVETICA 1
#define NEWCENSCH 2
#define SYMBOL 3
#define TIMES 4

#define NORMAL 0
#define BOLD 1
#define MEDIUM 2

#define ITALIC 1
#define NOITALIC 2

extern char *fontname;
extern int FontClass;
extern int FontFamily;
extern int FontWeight;
extern int FontSlant;
extern int FontSize;
extern int FontColour;

extern char *fontclass[CLASS];
extern char *family[FAMILY];
extern char *weight[WEIGHT];
extern char *slant[SLANT];
extern char *size[SIZE];

#ifndef _NO_PROTO 
void XmgfSetFont(void);
void FNTNCB(Widget w, caddr_t client_data, caddr_t call_data);
void FNTWCB(Widget w, caddr_t client_data, caddr_t call_data);
void FNTICB(Widget w, caddr_t client_data, caddr_t call_data);
void FNTSCB(Widget w, caddr_t client_data, caddr_t call_data);
int  GetFontNumber(char *FontName);
int  GetFontWeight(char *Weight);
int  GetFontSlant(char *Slant);
#else 
void XmgfSetFont();
void FNTNCB();
void FNTWCB();
void FNTICB();
void FNTSCB();
int  GetFontNumber();
int  GetFontWeight();
int  GetFontSlant();
#endif 

